==> smartgwtee-eval-4.1p.zip: com/smartgwt/client/docs/Positioning.java <==

package com.smartgwt.client.docs;

/**
 * Horizontal and vertical location on the page
 * @see com.smartgwt.client.widgets.Canvas#setSnapTo
 * @see com.smartgwt.client.widgets.Canvas#getSnapTo
 * @see com.smartgwt.client.widgets.Canvas#setSnapEdge
 * @see com.smartgwt.client.widgets.Canvas#getSnapEdge
 * @see com.smartgwt.client.widgets.Canvas#setRect
 * @see com.smartgwt.client.widgets.Canvas#getLeft
 * @see com.smartgwt.client.widgets.Canvas#setLeft
 * @see com.smartgwt.client.widgets.Canvas#getTop
 * @see com.smartgwt.client.widgets.Canvas#setTop
 * @see com.smartgwt.client.widgets.Canvas#getRight
 * @see com.smartgwt.client.widgets.Canvas#getBottom
 * @see com.smartgwt.client.widgets.Canvas#getScrollLeft
 * @see com.smartgwt.client.widgets.Canvas#getScrollTop
 * @see com.smartgwt.client.widgets.Canvas#setPageLeft
 * @see com.smartgwt.client.widgets.Canvas#setPageTop
 * @see com.smartgwt.client.widgets.Canvas#getPageLeft
 * @see com.smartgwt.client.widgets.Canvas#getPageTop
 * @see com.smartgwt.client.widgets.Canvas#getPageRight
 * @see com.smartgwt.client.widgets.Canvas#getPageBottom
 * @see com.smartgwt.client.widgets.Canvas#containsPoint
 * @see com.smartgwt.client.widgets.Canvas#visibleAtPoint
 * @see com.smartgwt.client.widgets.Canvas#intersects
 * @see com.smartgwt.client.widgets.Canvas#intersectsRect
 * @see com.smartgwt.client.widgets.Canvas#containsEvent
 * @see com.smartgwt.client.widgets.Canvas#getOffsetX
 * @see com.smartgwt.client.widgets.Canvas#getOffsetY
 * @see com.smartgwt.client.widgets.Canvas#moveBy
 * @see com.smartgwt.client.widgets.Canvas#moveTo
 * @see com.smartgwt.client.widgets.Canvas#getVSnapOrigin
 * @see com.smartgwt.client.widgets.Canvas#getHSnapOrigin
 * @see com.smartgwt.client.widgets.Canvas#setOverflow
 * @see com.smartgwt.client.widgets.drawing.DrawItem#getPageLeft
 * @see com.smartgwt.client.widgets.drawing.DrawItem#getPageTop
 * @see com.smartgwt.client.widgets.grid.ListGrid#getRowTop
 * @see com.smartgwt.client.widgets.grid.ListGrid#getRowPageTop
 * @see com.smartgwt.client.widgets.grid.ListGrid#getColumnLeft
 * @see com.smartgwt.client.widgets.grid.ListGrid#getColumnPageLeft
 * @see com.smartgwt.client.widgets.grid.ListGrid#getColumnWidth
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCellPageRect
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDrawnRowHeight
 * @see com.smartgwt.client.widgets.Button#setAlign
 * @see com.smartgwt.client.widgets.Button#setVAlign
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getRect
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getPageRect
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getLeft
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getTop
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getPageLeft
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getPageTop
 * @see com.smartgwt.client.widgets.tab.ImgTab#getAlign
 * @see com.smartgwt.client.widgets.Canvas#getHtmlElement
 * @see com.smartgwt.client.widgets.Canvas#getHtmlPosition
 * @see com.smartgwt.client.widgets.Canvas#getPosition
 * @see com.smartgwt.client.widgets.Canvas#getLeft
 * @see com.smartgwt.client.widgets.Canvas#getTop
 * @see com.smartgwt.client.widgets.Label#getAlign
 * @see com.smartgwt.client.widgets.Label#getValign
 * @see com.smartgwt.client.types.Positioning
 */
public interface Positioning {
}

==> smartgwtee-eval-5.1p.zip: com/smartgwt/client/docs/Positioning.java <==

package com.smartgwt.client.docs;

/**
 * Horizontal and vertical location on the page
 * @see com.smartgwt.client.widgets.Canvas#defaultPageSpace
 * @see com.smartgwt.client.types.Positioning
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getRect
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getPageRect
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getLeft
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getTop
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getPageLeft
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getPageTop
 * @see com.smartgwt.client.widgets.grid.ListGrid#getRowTop
 * @see com.smartgwt.client.widgets.grid.ListGrid#getRowPageTop
 * @see com.smartgwt.client.widgets.grid.ListGrid#getColumnLeft
 * @see com.smartgwt.client.widgets.grid.ListGrid#getColumnPageLeft
 * @see com.smartgwt.client.widgets.grid.ListGrid#getColumnWidth
 * @see com.smartgwt.client.widgets.grid.ListGrid#getCellPageRect
 * @see com.smartgwt.client.widgets.grid.ListGrid#getDrawnRowHeight
 * @see com.smartgwt.client.widgets.Canvas#setSnapTo
 * @see com.smartgwt.client.widgets.Canvas#getSnapTo
 * @see com.smartgwt.client.widgets.Canvas#setSnapEdge
 * @see com.smartgwt.client.widgets.Canvas#getSnapEdge
 * @see com.smartgwt.client.widgets.Canvas#setRect
 * @see com.smartgwt.client.widgets.Canvas#getLeft
 * @see com.smartgwt.client.widgets.Canvas#setLeft
 * @see com.smartgwt.client.widgets.Canvas#getTop
 * @see com.smartgwt.client.widgets.Canvas#setTop
 * @see com.smartgwt.client.widgets.Canvas#setLeavePageSpace
 * @see com.smartgwt.client.widgets.Canvas#getRight
 * @see com.smartgwt.client.widgets.Canvas#getBottom
 * @see com.smartgwt.client.widgets.Canvas#getScrollLeft
 * @see com.smartgwt.client.widgets.Canvas#getScrollTop
 * @see com.smartgwt.client.widgets.Canvas#setPageLeft
 * @see com.smartgwt.client.widgets.Canvas#setPageTop
 * @see com.smartgwt.client.widgets.Canvas#getPageLeft
 * @see com.smartgwt.client.widgets.Canvas#getPageTop
 * @see com.smartgwt.client.widgets.Canvas#getPageRight
 * @see com.smartgwt.client.widgets.Canvas#getPageBottom
 * @see com.smartgwt.client.widgets.Canvas#containsPoint
 * @see com.smartgwt.client.widgets.Canvas#visibleAtPoint
 * @see com.smartgwt.client.widgets.Canvas#intersects
 * @see com.smartgwt.client.widgets.Canvas#intersectsRect
 * @see com.smartgwt.client.widgets.Canvas#encloses
 * @see com.smartgwt.client.widgets.Canvas#enclosesRect
 * @see com.smartgwt.client.widgets.Canvas#containsEvent
 * @see com.smartgwt.client.widgets.Canvas#getOffsetX
 * @see com.smartgwt.client.widgets.Canvas#getOffsetY
 * @see com.smartgwt.client.widgets.Canvas#moveBy
 * @see com.smartgwt.client.widgets.Canvas#moveTo
 * @see com.smartgwt.client.widgets.Canvas#getVSnapOrigin
 * @see com.smartgwt.client.widgets.Canvas#getHSnapOrigin
 * @see com.smartgwt.client.widgets.Canvas#placeNear
 * @see com.smartgwt.client.widgets.Canvas#setOverflow
 * @see com.smartgwt.client.widgets.drawing.DrawItem#getPageLeft
 * @see com.smartgwt.client.widgets.drawing.DrawItem#getPageTop
 * @see com.smartgwt.client.widgets.Button#setAlign
 * @see com.smartgwt.client.widgets.Button#setVAlign
 * @see com.smartgwt.client.widgets.tab.ImgTab#getAlign
 * @see com.smartgwt.client.widgets.Canvas#getHtmlElement
 * @see com.smartgwt.client.widgets.Canvas#getHtmlPosition
 * @see com.smartgwt.client.widgets.Canvas#getPosition
 * @see com.smartgwt.client.widgets.Canvas#getLeft
 * @see com.smartgwt.client.widgets.Canvas#getTop
 * @see com.smartgwt.client.widgets.Canvas#getLeavePageSpace
 * @see com.smartgwt.client.widgets.Label#getAlign
 * @see com.smartgwt.client.widgets.Label#getValign
 */
public interface Positioning {
}
